@@ -174,7 +174,7 @@ class BitmexOrder:
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
 
     def price_decimals(self, symbol, price):
-        if symbol == 'XBUTSD':
+        if symbol == 'XBTUSD':
             return round(price * 2) / 2
         elif symbol == 'ETHUSD':
             return round(price * 20) / 20
@@ -223,7 +223,7 @@ class BitmexOrder:
             order_res = self.client.client.Order.Order_cancel(
                 clOrdID=orderId
             ).result()
-            self.props[symbol].wait_stop = False
+            self.props[symbol]['wait_stop'] = False
             return order_res
         except (HTTPBadRequest, HTTPNotFound) as e:
             print("Error canceling order.", e, flush=True)
@@ -242,7 +242,7 @@ class BitmexOrder:
                 stopPx=self.price_decimals(symbol, entry), execInst='LastPrice'
             ).result()
             self.props[symbol]['qty'] = orderQty
-            self.props[symbol].wait_stop = True
+            self.props[symbol]['wait_stop'] = True
             self.props[symbol]['SL'] = sl
             self.props[symbol]['TP'] = tp
             self.props[symbol]['entry'] = entry
@@ -277,7 +277,7 @@ class BitmexOrder:
             print("Error placing market order.", e, flush=True)
 
     def modifiy_stop(self, symbol, newPrice):
-        if self.props[symbol].wait_stop:
+        if self.props[symbol]['wait_stop']:
             try:
                 res = self.client.client.Order.Order_amend(
                     orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
